#[non_exhaustive]pub enum DecisionAuditDecodeError {
Entry(AuditEntryError),
UnexpectedShape {
field: &'static str,
},
MissingPayload,
Json(Error),
Identity(GatekeepError),
}Expand description
Errors returned while decoding a Dovecote event as a Gatekeep decision audit entry.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Entry(AuditEntryError)
The payload represented a current entry but failed its tenant-binding invariants.
UnexpectedShape
A required Dovecote event attribute did not match Gatekeep’s contract.
MissingPayload
The event did not carry JSON data.
Json(Error)
The event payload was not a valid typed entry.
Identity(GatekeepError)
The event identity suffix was not a valid typed decision identity.