#[non_exhaustive]pub enum DecisionAuditEventError {
PayloadTooLarge,
Entry(AuditEntryError),
Json(Error),
Identity(GatekeepError),
Validation(ValidationError),
}Expand description
Errors while converting a typed Gatekeep entry into a validated Dovecote event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PayloadTooLarge
Encoded evidence exceeds the supported one MiB payload bound.
Entry(AuditEntryError)
The entry is not a valid current decision record.
Json(Error)
The typed entry could not be serialized as JSON.
Identity(GatekeepError)
The entry uses the migration-only legacy identity namespace.
Validation(ValidationError)
The generated event identity or event content failed Dovecote validation.