#[non_exhaustive]pub enum LegacyDecisionAuditDecodeError {
UnexpectedShape {
field: &'static str,
},
MissingPayload,
Json(Error),
Identity,
Tenant,
}Expand description
Errors returned while decoding a historical audit event explicitly.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnexpectedShape
A required Dovecote event attribute did not match Gatekeep’s contract.
MissingPayload
The event did not carry JSON data.
Json(Error)
The event payload was not a valid historical typed entry.
Identity
The event identity did not match the historical payload identity.
Tenant
The storage tenant differs from the historical payload tenant.