#[non_exhaustive]pub enum SqlxDriverError {
UnsupportedUrlScheme {
scheme: Option<String>,
},
DriverNotEnabled {
driver: &'static str,
},
BackendMismatch {
expected: &'static str,
actual: &'static str,
},
}Expand description
Database driver configuration error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedUrlScheme
The URL scheme is not recognized as a SQLx database driver.
DriverNotEnabled
The URL selects a driver whose feature was not enabled.
BackendMismatch
The configured driver does not match the selected backend.