PgFactPredicates

Trait PgFactPredicates 

pub trait PgFactPredicates {
    // Required method
    fn predicate(&self, fact: &FactId, cx: &Context) -> Option<PgFragment>;
}
Maps a residual fact to a trusted Postgres predicate over the candidate row.

Required Methods

fn predicate(&self, fact: &FactId, cx: &Context) -> Option<PgFragment>

Returns a predicate for the given fact, or None when the fact cannot be represented by this backend.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors