SqlxFactPredicates

Trait SqlxFactPredicates 

pub trait SqlxFactPredicates<B>{
    // Required method
    fn predicate(&self, fact: &FactId, cx: &Context) -> Option<SqlxFragment<B>>;
}
Maps a residual fact to a trusted predicate over the candidate row.

Required Methods

fn predicate(&self, fact: &FactId, cx: &Context) -> Option<SqlxFragment<B>>

Returns a predicate for the given fact, or None when the fact cannot be represented by this backend.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> SqlxFactPredicates<PostgresBackend> for T

Available on crate feature postgres only.