pub trait GatekeepSqlxBackend:
Clone
+ Copy
+ Debug
+ Send
+ Sync
+ 'static {
type Database: Database;
const DRIVER: SqlxDriver;
const NAME: &'static str;
const MIN_FUNCTION: &'static str;
const MAX_FUNCTION: &'static str;
const GRADE_FUNCTION_PROPAGATES_NULL: bool;
// Required methods
fn push_placeholder(sql: &mut String, index: usize);
fn push_bind(builder: &mut QueryBuilder<Self::Database>, value: &SqlxValue);
}Expand description
SQLx backend supported by gatekeep lowering.
Required Associated Constants
Sourceconst DRIVER: SqlxDriver
const DRIVER: SqlxDriver
Database driver represented by this backend.
Sourceconst MIN_FUNCTION: &'static str
const MIN_FUNCTION: &'static str
Name of the SQL function that returns the lower of two non-null grades.
Sourceconst MAX_FUNCTION: &'static str
const MAX_FUNCTION: &'static str
Name of the SQL function that returns the higher of two non-null grades.
Sourceconst GRADE_FUNCTION_PROPAGATES_NULL: bool
const GRADE_FUNCTION_PROPAGATES_NULL: bool
Whether the backend’s grade functions return NULL when any input is
NULL.
Required Associated Types
Required Methods
Sourcefn push_placeholder(sql: &mut String, index: usize)
fn push_placeholder(sql: &mut String, index: usize)
Appends one bind placeholder to rendered SQL.
Sourcefn push_bind(builder: &mut QueryBuilder<Self::Database>, value: &SqlxValue)
fn push_bind(builder: &mut QueryBuilder<Self::Database>, value: &SqlxValue)
Appends one typed bind value to a SQLx query builder.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl GatekeepSqlxBackend for PostgresBackend
Available on crate feature postgres only.
impl GatekeepSqlxBackend for PostgresBackend
Available on crate feature
postgres only.